@@ -37,6 +37,7 @@ ENTRY *alloc_entry(int svc)
     entry->flags = 0;
     entry->timer = NULL;
     entry->vccs = NULL;
+    entry->notify = NULL;
     entry->itf = NULL;
     return entry;
 }
@@ -94,13 +95,15 @@ static void output(const char *fmt,...)
 static void dump_vcc(VCC *vcc)
 {
     struct sockaddr_atmsvc addr;
-    char buffer[MAX_ATM_ADDR_LEN+1];
+    char addr_buf[MAX_ATM_ADDR_LEN+1];
+    char qos_buf[MAX_ATM_QOS_LEN+1];
+    struct atm_qos qos;
     int size;
 
     size = sizeof(addr);
     if (getpeername(vcc->fd,(struct sockaddr *) &addr,&size) < 0) {
 	diag(COMPONENT,DIAG_ERROR,"getpeername: %s",strerror(errno));
-	strcpy(buffer,"<getsocknam error>");
+	strcpy(addr_buf,"<getsocknam error>");
     }
     else {
 #if 0
@@ -110,11 +113,31 @@ static void dump_vcc(VCC *vcc)
 	    printf("%02X ",((unsigned char *) &addr)[i]);
 	printf("\n");
 #endif
-	if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *) &addr,
-	  pretty) < 0) strcpy(buffer,"<atm2text error>");
+	if (atm2text(addr_buf,sizeof(addr_buf),(struct sockaddr *) &addr,
+	  pretty) < 0) strcpy(addr_buf,"<atm2text error>");
+    }
+    output("  %s%s",addr_buf,vcc->connecting ? ", connecting" :
+      !vcc->entry || !vcc->entry->svc ? "" : vcc->active ? " (active)" :
+      " (passive)");
+    if (vcc->connecting) return;
+    size = sizeof(qos);
+    if (getsockopt(vcc->fd,SOL_ATM,SO_ATMQOS,&qos,&size) < 0)
+	sprintf(qos_buf,"<no qos: %s>",strerror(errno));
+    else {
+	if (vcc->entry && qos_equal(&vcc->entry->qos,&qos)) return;
+	if (qos2text(qos_buf,sizeof(qos_buf),&qos,0) < 0)
+	    strcpy(qos_buf,"<invalid qos>");
+	output("    QOS: %s",qos_buf);
+    }
+}
+
+
+static void dump_vccs(VCC *vcc)
+{
+    while (vcc) {
+	dump_vcc(vcc);
+	vcc = vcc->next;
     }
-    output("  %s%s",buffer,vcc->connecting ? ", connecting" :
-      !vcc->entry->svc ? "" : vcc->active ? " (active)" : " (passive)");
 }
 
 
@@ -124,10 +147,9 @@ static void dump_entries(ENTRY *list)
 	"???",	"com", "PERM", "PUBL",			/* 0x0001-0x0008 */
 	"trailers", "netmask", "dontpub", "magic",	/* 0x0010-0x0080 */
 	"???", "???", "???", "???",			/* 0x0100-0x0800 */
-	"NULL", "ARPSRV", "???" };			/* 0x1000-0x8000 */
+	"NULL", "ARPSRV", "NOVC" };			/* 0x1000-0x8000 */
     /* lower case flags are not used by ATMARP */
     ENTRY *entry;
-    VCC *vcc;
     char addr_buf[MAX_ATM_ADDR_LEN+1];
     char qos_buf[MAX_ATM_QOS_LEN+1];
     char tmp[100]; /* large enough for all flags */
@@ -152,9 +174,17 @@ static void dump_entries(ENTRY *list)
 	if (entry->itf && !qos_equal(&entry->itf->qos,&entry->qos)) {
 	    if (qos2text(qos_buf,sizeof(qos_buf),&entry->qos,0) < 0)
 		strcpy(qos_buf,"<error>");
-		output("  QOS: %s",qos_buf);
+	    output("  QOS: %s",qos_buf);
 	}
-	for (vcc = entry->vccs; vcc; vcc = vcc->next) dump_vcc(vcc);
+	if (entry->notify) {
+	    NOTIFY *notify;
+	    int count;
+
+	    count = 0;
+	    for (notify = entry->notify; notify; notify = notify->next) count++;
+	    output("  %d quer%s pending",count,count == 1 ? "y" : "ies");
+	}
+	dump_vccs(entry->vccs);
     }
 }
 
@@ -181,9 +211,9 @@ static void dump_all(void)
     for (itf = itfs; itf; itf = itf->next) dump_itf(itf);
     output("----- Unknown incoming connections -----");
     dump_entries(unknown_incoming);
+    output("----- Incoming unidirectional connections -----");
+    dump_vccs(unidirectional_vccs);
     output("----- End of dump -----");
-    if (out_file) {
-    }
 }
 
 
