@@ -28,6 +28,11 @@ typedef enum {
     as_valid,		/* valid */
 } ADDR_STATE;
 
+typedef struct _notify {
+    UN_CTX ctx;		/* peer to send reply to */
+    struct _notify *next;
+} NOTIFY;
+
 typedef struct _entry {
     ADDR_STATE state;
     int svc;
@@ -38,7 +43,8 @@ typedef struct _entry {
     TIMER *timer; /* currently active timer or NULL */
     int timeout; /* current interval - only necessary if using retries */
     int retries;
-    struct _vcc *vccs;
+    VCC *vccs;
+    NOTIFY *notify;
     struct _itf *itf;
     struct _entry *prev,*next; /* undefined if itf == NULL */
 } ENTRY;
@@ -66,6 +72,7 @@ extern const char *vcc_state_name[];
 
 extern ITF *itfs;
 extern ENTRY *unknown_incoming;
+extern VCC *unidirectional_vccs;
 
 extern int pretty,merge;
 
