@@ -98,6 +98,7 @@
 #ifndef LEC_CTRL_H
 #define LEC_CTRL_H
 #include "cm_sap.h"
+#include "lane2.h"   /* LANE2 */
 /*************************************************************************
  * Callbacks
  *************************************************************************/
@@ -283,7 +284,11 @@ STATUS lc_register (HANDLE       lc_handle,
                     BOOLEAN      proxy_flag,
                     HANDLE       lport_handle,
                     char        *p_text,
-                    HANDLE      *p_lc_elan_handle);
+                    HANDLE      *p_lc_elan_handle,
+                    BOOLEAN      v2_capable,
+                    ADDR_ATM     preferred_les,
+                    ADDR_L3      l3_address,
+                    const char  *foreId); /* Info string displayed by Fore switches */
 
 
 /*++
