@@ -1,6 +1,6 @@
 /* atmaddr.c - Get/set local ATM adresses */
 
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996,1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -8,7 +8,6 @@
 #include <string.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
-#include <linux/atm.h>
 #include <linux/atmdev.h>
 
 #include "atm.h"
