@@ -28,9 +28,10 @@ static void construct(FIELD *start)
     TAG *scan;
     int patch_here;
 
+    patch_here = 0; /* for gcc */
     for (walk = start; walk; walk = walk->next) {
 	if (walk->structure) {
-	    construct(walk->structure->block);
+	    construct(walk->my_block);
 	    continue;
 	}
 	if (!walk->value)
@@ -104,9 +105,10 @@ static void parser(FIELD *start,int level,int group)
     int count,patch_here;
     BREAK *brk,*tmp_brks,*next;
 
+    patch_here = 0; /* for gcc */
     for (walk = start; walk; walk = walk->next) {
 	if (walk->structure) {
-	    parser(walk->structure->block,level,group);
+	    parser(walk->my_block,level,group);
 	    continue;
 	}
 	if (walk->brk) {
