@@ -1,9 +1,10 @@
 /* sscop.c - SSCOP (Q.2110) protocol */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
+#include <stdint.h>
 #include <stdarg.h>
 #include <string.h>
 #include <netinet/in.h> /* for htonl */
@@ -141,7 +142,7 @@ static void maa_error(void *arg,char code,int count)
 
 static int sdu_length(BUFFER *buf)
 {
-    return buf->length-4-SSCOP_PAD(*(__u32 *) ((char *) buf->data+
+    return buf->length-4-SSCOP_PAD(*(uint32_t *) ((char *) buf->data+
       buf->length-4));
 }
 
@@ -150,7 +151,7 @@ static BUFFER *build_pdu(SSCOP_DSC *dsc,unsigned char type,void *data,
   int num)
 {
     BUFFER *buf;
-    __u32 *trailer;
+    uint32_t *trailer;
     int pad;
 
     buf = buffer_create(num+12,dsc->vt_s); /* space for trailers */
@@ -158,11 +159,11 @@ static BUFFER *build_pdu(SSCOP_DSC *dsc,unsigned char type,void *data,
 	memset((char *) buf->data+(num & ~3),0,4); /* clear padding area */
 	memcpy((unsigned char *) buf->data,data,num);
 	pad = (4-(num & 3)) & 3;
-	trailer = (__u32 *) ((char *) buf->data+num+pad);
+	trailer = (uint32_t *) ((char *) buf->data+num+pad);
     }
     else {
 	pad = 0;
-	trailer = (__u32 *) buf->data;
+	trailer = (uint32_t *) buf->data;
     }
     diag(COMPONENT,DIAG_DEBUG,"generating %s PDU",pdu_name[type]);
     switch (type) {
@@ -227,7 +228,7 @@ static void emit_pdu(SSCOP_DSC *dsc,BUFFER *buf)
     }
     if (dsc->ops->cpcs_send)
 	dsc->ops->cpcs_send(dsc->user,buf->data,buf->length);
-    switch (SSCOP_TYPE(*(__u32 *) ((char *) buf->data+buf->length-4))) {
+    switch (SSCOP_TYPE(*(uint32_t *) ((char *) buf->data+buf->length-4))) {
 	case SSCOP_BGN:
 	    last = &dsc->last_bgn;
 	    break;
@@ -286,7 +287,7 @@ static void bad_pdu(SSCOP_DSC *dsc,unsigned char type)
 
 static void send_ustat(SSCOP_DSC *dsc,int first,int last)
 {
-    __u32 range[2];
+    uint32_t range[2];
 
     range[0] = htonl(first);
     range[1] = htonl(last);
@@ -710,7 +711,7 @@ static void data_poll(SSCOP_DSC *dsc,int s) /* 20.41-42 */
 {
     int curr,i;
 
-    if (!dsc->list) dsc->list = alloc(dsc->cf_max_stat*sizeof(__u32));
+    if (!dsc->list) dsc->list = alloc(dsc->cf_max_stat*sizeof(uint32_t));
     if (NORM_RX(dsc->vr_h) > NORM_RX(s)) {
 	start_error_recov(dsc,'Q');
 	return;
@@ -779,11 +780,11 @@ static void data_ustat(SSCOP_DSC *dsc,int mr,int r,int e1,int e2) /* 20.43 */
 }
 
 
-static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,__u32 *list,
+static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,uint32_t *list,
   int length) /* 20.44-46 */
 {
     BUFFER *buf,*buf2;
-    __u32 *curr,tmp;
+    uint32_t *curr,tmp;
     int i,count,seq1,seq2;
 
     if (NEGATIVE(NORM_TXP(ps)) || NORM_TXP(ps) > NORM_TXP(dsc->vt_ps)) {
@@ -1430,8 +1431,8 @@ static int handle_sscop_pdu(SSCOP_DSC *dsc,void *msg,int size)
 		    data_poll(dsc,s);
 		    return 1;
 		case SSCOP_USTAT:
-		    data_ustat(dsc,mr,r,SSCOP_N(((__u32 *) msg)[0]),
-		      SSCOP_N(((__u32 *) msg)[1]));
+		    data_ustat(dsc,mr,r,SSCOP_N(((uint32_t *) msg)[0]),
+		      SSCOP_N(((uint32_t *) msg)[1]));
 		    return 1;
 		case SSCOP_STAT:
 		    data_stat(dsc,ps,mr,r,msg,length/4);
