@@ -28,14 +28,14 @@ extern int yyparse(void);
 extern FILE *yyin;
 
 
-static void from_fab(CALL *call,int okay,void *user)
+static void from_fab(CALL *call,int cause,void *more,void *user)
 {
-    printf("%p: fab returns %d\n",call,okay);
+    printf("%p: fab returns cause %d\n",call,cause);
     print_call(call);
 
     switch (call->state) {
 	case cs_indicated:
-	    if (okay) {
+	    if (!cause) {
 		/* send connect to called and enter state cs_rm_accepted */
 		send_identify(call);
 		send_connect(call);
@@ -43,26 +43,26 @@ static void from_fab(CALL *call,int okay,void *user)
 	    }
 	    else {
 		/* send as_reject to caller and enter state cs_invalid */
-		send_reject_not_id(call->in.sig,-EREMOTEIO); /* @@@ */
+		send_reject_not_id(call->in.sig,-EREMOTEIO); /* @@@  use cause*/
 		new_state(call,cs_invalid);
 		free_call(call);
 	    }
 	    break;
 	case cs_called_accepted:
-	    if (okay) {
+	    if (!cause) {
 		/* send accept to caller */
 		send_accept(call);
 		new_state(call,cs_rm_accepted2);
 	    }
 	    else {
 		/* send reject to caller and close to called */
-		send_reject(call,-EREMOTEIO);
+		send_reject(call,-EREMOTEIO); /* @@@ use cause */
 		send_close(call,CALLED);
 		new_state(call,cs_rejected);
 	    }
 	    break;
 	case cs_rejecting:
-	    if (!okay) free_call(call);
+	    if (cause) free_call(call);
 	    else {
 		/* free resources */
 		new_state(call, cs_free_rm);
@@ -70,7 +70,7 @@ static void from_fab(CALL *call,int okay,void *user)
 	    }
 	    break;
 	case cs_free_rm:
-	    if (!okay) printf("Error: RM couldn't free resources\n");
+	    if (cause) printf("Error: RM couldn't free resources\n");
 	    free_call(call);
 	    break;
 	default:
